#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Sep 22 11:17:10 2022

@author: user
"""


# import wayfinder